"use client";
import React, { useState, useEffect } from 'react';
import { ArrowUpIcon, ArrowDownIcon } from 'lucide-react';
import PropertyDetailsModal from './agentRejectedDetails/PropertyDetailsModal';

const AgentRejectedProperty = ({
  userAgentData,
  rejectedAgentUsersData,
  totalPostDetails,
  totalAgentPostDetails,
  totalAgentRejected,
  totalAgentApproval,
  onStatusChange,
}) => {
  const [selectedProperty, setSelectedProperty] = useState(null);
  const [sortDirection, setSortDirection] = useState('desc');
  const [sortedData, setSortedData] = useState([]);
  const [isInitialLoad, setIsInitialLoad] = useState(true);

  const sortData = (data, direction) => {
    return [...data].sort((a, b) => {
      // Sort by the created_at date of the first post in each agent's post_details
      const dateA = new Date(a.post_details[0]?.created_at || 0);
      const dateB = new Date(b.post_details[0]?.created_at || 0);
      return direction === 'asc' ? dateA - dateB : dateB - dateA;
    });
  };

  useEffect(() => {
    if (rejectedAgentUsersData) {
      if (isInitialLoad) {
        // On initial load/refresh, always sort by latest first
        const initialSorted = sortData(rejectedAgentUsersData, 'desc');
        setSortedData(initialSorted);
        setIsInitialLoad(false);
      } else {
        // During normal use, use the current sort direction
        const sorted = sortData(rejectedAgentUsersData, sortDirection);
        setSortedData(sorted);
      }
    }
  }, [rejectedAgentUsersData, sortDirection, isInitialLoad]);

  useEffect(() => {
    return () => {
      setIsInitialLoad(true);
    };
  }, []);

  const handleViewDetails = (agent, post) => {
    const propertyData = {
      id: post.id,
      location: `${post.land_distance[0]?.locality}, ${post.land_distance[0]?.city}`,
      price: `₹${post.land_price[0]?.price} ${post.land_price[0]?.per_unit}`,
      number: agent.mobile_number,
      status: post.status === null ? 'Rejected' : post.status === 1 ? 'Approved' : 'Pending',
      type: post.post_type,
      date: new Date(post.created_at).toLocaleDateString(),
      images: post.land_photos.map(photo => {
        const mainImg = photo.main_img;
        const thumbImages = photo.thumbnails.map(thumb => thumb.thumb_photos);
        return { mainImg, thumbImages };
      }),
      youtube: post.land_photos[0]?.youtube_link,
      drone: post.land_photos[0]?.drone_link,  
      dimensions: post.dimension,
      landSize: `${post.land_size} ${post.land_size_unit}`,
      facing: post.land_distance[0]?.plot_facing,
      basicRequirements: JSON.parse(post.land_price.basic_req || "[]"),
      distances: post.land_distance[0]?.distance_form
    };
    setSelectedProperty(propertyData);
  };

  const handleCloseModal = () => {
    setSelectedProperty(null);
  };

  const handleApproveStatus = (postId) => {
    onStatusChange(postId, 'approve');
  };

  const handleWaitingStatus = (postId) => {
    onStatusChange(postId, 'waiting');
  };

  const toggleSort = () => {
    setIsInitialLoad(false);
    const newDirection = sortDirection === 'asc' ? 'desc' : 'asc';
    setSortDirection(newDirection);
  };

  return (
    <div className="flex flex-col space-y-6 p-4 sm:p-6">
      {/* Header Section */}
      <div className="flex flex-col gap-3 sm:flex-row sm:items-center sm:justify-between">
        <div className="flex items-center gap-2">
          <h1 className="text-xl sm:text-2xl font-semibold text-gray-900">
            Agents Rejected Property
          </h1>
          <span className="text-xs bg-red-100 text-red-800 px-2 py-0.5 rounded-full font-semibold">
            Rejected
          </span>
        </div>
      </div>

      {/* Statistics Grid */}
      <div className="grid gap-4 grid-cols-1 sm:grid-cols-2 lg:grid-cols-4">
        {/* Total Properties Card */}
        <div className="rounded-lg border border-gray-200 bg-white p-4 shadow-sm">
          <div className="flex items-center justify-between">
            <h3 className="text-sm font-medium text-gray-600">Total Properties</h3>
            <svg className="h-5 w-5 text-gray-400" fill="none" stroke="currentColor" viewBox="0 0 24 24">
              <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M19 21V5a2 2 0 00-2-2H7a2 2 0 00-2 2v16m14 0h2m-2 0h-5m-9 0H3m2 0h5M9 7h1m-1 4h1m4-4h1m-1 4h1m-5 10v-5a1 1 0 011-1h2a1 1 0 011 1v5m-4 0h4" />
            </svg>
          </div>
          <div className="mt-2">
            <div className="text-2xl font-bold text-gray-900">{totalPostDetails || 0}</div>
            <p className="text-xs text-gray-600">+12% from last month</p>
          </div>
        </div>

        {/* Total Agents Properties Card */}
        <div className="rounded-lg border border-gray-200 bg-white p-4 shadow-sm">
          <div className="flex items-center justify-between">
            <h3 className="text-sm font-medium text-gray-600">Total Agents Properties</h3>
            <svg className="h-5 w-5 text-gray-400" fill="none" stroke="currentColor" viewBox="0 0 24 24">
              <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M17 20h5v-2a3 3 0 00-5.356-1.857M17 20H7m10 0v-2c0-.656-.126-1.283-.356-1.857M7 20H2v-2a3 3 0 015.356-1.857M7 20v-2c0-.656.126-1.283.356-1.857m0 0a5.002 5.002 0 019.288 0M15 7a3 3 0 11-6 0 3 3 0 016 0zm6 3a2 2 0 11-4 0 2 2 0 014 0zM7 10a2 2 0 11-4 0 2 2 0 014 0z" />
            </svg>
          </div>
          <div className="mt-2">
            <div className="text-2xl font-bold text-gray-900">{totalAgentPostDetails || 0}</div>
            <p className="text-xs text-gray-600">+3 this month</p>
          </div>
        </div>

        {/* Rejected Properties Card */}
        <div className="rounded-lg border border-gray-200 bg-white p-4 shadow-sm">
          <div className="flex items-center justify-between">
            <h3 className="text-sm font-medium text-gray-600">Rejected Property</h3>
            <svg className="h-5 w-5 text-gray-400" fill="none" stroke="currentColor" viewBox="0 0 24 24">
              <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M9 12l2 2 4-4m6 2a9 9 0 11-18 0 9 9 0 0118 0z" />
            </svg>
          </div>
          <div className="mt-2">
            <div className="text-2xl font-bold text-gray-900">{totalAgentRejected || 0}</div>
            <p className="text-xs text-gray-600">Awaiting admin review</p>
          </div>
        </div>

        {/* Agent Approved Properties Card */}
        <div className="rounded-lg border border-gray-200 bg-white p-4 shadow-sm">
          <div className="flex items-center justify-between">
            <h3 className="text-sm font-medium text-gray-600">Agent Approved Properties</h3>
            <svg className="h-5 w-5 text-gray-400" fill="none" stroke="currentColor" viewBox="0 0 24 24">
              <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M12 8c-1.657 0-3 .895-3 2s1.343 2 3 2 3 .895 3 2-1.343 2-3 2m0-8c1.11 0 2.08.402 2.599 1M12 8V7m0 1v8m0 0v1m0-1c-1.11 0-2.08-.402-2.599-1M21 12a9 9 0 11-18 0 9 9 0 0118 0z" />
            </svg>
          </div>
          <div className="mt-2">
            <div className="text-2xl font-bold text-gray-900">{totalAgentApproval || 0}</div>
            <p className="text-xs text-gray-600">Approved by Admin</p>
          </div>
        </div>
      </div>

      {/* Properties Table Section */}
      <div className="rounded-lg border border-gray-200 bg-white shadow-sm overflow-hidden">
        <div className="border-b border-gray-200 px-4 py-4 sm:px-6 flex justify-between items-center">
          <h2 className="text-lg font-semibold text-gray-900">Recent Rejected Properties</h2>
          <button
            onClick={toggleSort}
            className="flex items-center space-x-2 px-3 py-2 bg-white border border-gray-300 rounded-md shadow-sm text-sm font-medium text-gray-700 hover:bg-gray-50 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-blue-500"
          >
            <span>Sort by Date</span>
            {sortDirection === 'asc' ? (
              <ArrowUpIcon className="h-4 w-4" />
            ) : (
              <ArrowDownIcon className="h-4 w-4" />
            )}
          </button>
        </div>
        <div className="overflow-x-auto">
          {sortedData.length > 0 ? (
            <table className="w-full">
              <thead>
                <tr className="border-b border-gray-200 bg-gray-50">
                  <th className="px-4 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider sm:px-6">Agent Name</th>
                  <th className="px-4 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider sm:px-6">Land Type</th>
                  <th className="px-4 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider sm:px-6">Land Size</th>
                  <th className="px-4 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider sm:px-6">City</th>
                  <th className="px-4 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider sm:px-6">Price</th>
                  <th className="px-4 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider sm:px-6">Details</th>
                  <th className="px-4 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider sm:px-6">Actions</th>
                </tr>
              </thead>
              <tbody className="bg-white divide-y divide-gray-200">
                {sortedData.map((agent) =>
                  agent.post_details.map((post) => (
                    <tr key={`${agent.id}-${post.id}`} className="hover:bg-gray-50">
                      <td className="px-4 py-4 whitespace-nowrap text-sm text-gray-900 sm:px-6">
                        {agent.name.charAt(0).toUpperCase() + agent.name.slice(1)}
                      </td>
                      <td className="px-4 py-4 whitespace-nowrap text-sm text-gray-500 sm:px-6">
                        {post.land_type.charAt(0).toUpperCase() + post.land_type.slice(1)}
                      </td>
                      <td className="px-4 py-4 whitespace-nowrap text-sm text-gray-900 sm:px-6">
                        {post.land_size} {post.land_size_unit}
                      </td>
                      <td className="px-4 py-4 whitespace-nowrap text-sm text-gray-500 sm:px-6">
                        {post.land_distance[0]?.city ? 
                          post.land_distance[0].city.charAt(0).toUpperCase() + 
                          post.land_distance[0].city.slice(1) : ""}
                      </td>
                      <td className="px-4 py-4 whitespace-nowrap text-sm text-gray-500 sm:px-6">
                        ₹ {post.land_price[0]?.price} {post.land_price[0]?.per_unit}
                      </td>
                      <td className="px-4 py-4 whitespace-nowrap text-sm sm:px-6">
                        <div className="flex items-center gap-2 sm:gap-4">
                          <button 
                            onClick={() => handleViewDetails(agent, post)}
                            className="text-blue-600 hover:text-blue-900"
                            aria-label="View details"
                          >
                            <svg xmlns="http://www.w3.org/2000/svg" className="h-5 w-5" fill="none" viewBox="0 0 24 24" stroke="currentColor">
                              <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M15 12a3 3 0 11-6 0 3 3 0 016 0z" />
                              <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M2.458 12C3.732 7.943 7.523 5 12 5c4.478 0 8.268 2.943 9.542 7-1.274 4.057-5.064 7-9.542 7-4.477 0-8.268-2.943-9.542-7z" />
                            </svg>
                          </button>
                        </div>
                      </td>

                      <td className="px-4 py-4 whitespace-nowrap text-sm sm:px-6">
                        <div className="flex items-center gap-2 sm:gap-4">

                          <button 
                            onClick={() => handleApproveStatus(post.id, 'approve')}
                            className="text-green-600 hover:text-green-900 flex items-center space-x-1">
                      <svg xmlns="http://www.w3.org/2000/svg" className="h-5 w-5" fill="none" viewBox="0 0 24 24" stroke="currentColor">
                        <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M9 12l2 2 4-4m6 2a9 9 0 11-18 0 9 9 0 0118 0z" />
                      </svg>
                      <span className="hidden sm:inline">Approve</span>
                    </button>





                         


                          <button                             onClick={() => handleWaitingStatus(post.id, 'waiting')}
 className="text-yellow-600 hover:text-yellow-900 flex items-center space-x-1">
  <svg
    xmlns="http://www.w3.org/2000/svg"
    className="h-5 w-5 animate-spin"
    fill="none"
    viewBox="0 0 24 24"
    stroke="currentColor"
  >
    <path
      strokeLinecap="round"
      strokeLinejoin="round"
      strokeWidth={2}
      d="M12 8v4l3 3m6-3a9 9 0 11-18 0 9 9 0 0118 0z"
    />
  </svg>
  <span className="hidden sm:inline">Waiting</span>
</button>



                        </div>
                      </td>
                    </tr>
                  ))
                )}
              </tbody>
            </table>
          ) : (
            <p className="p-4">No agent users found.</p>
          )}
        </div>
      </div>

      {/* Property Details Modal */}
      {selectedProperty && (
        <PropertyDetailsModal 
          property={selectedProperty} 
          onClose={handleCloseModal} 
        />
      )}
    </div>
  );
};

export default AgentRejectedProperty;